VERSION 8000;;8430
* ALKIS_Koordinaten_Listen.CSX    02.05.14
* -----------------------------------------------------------------------------
* @filedoc
* @file ALKIS_Koordinaten_Listen.CSX
* @brief <Koordinaten eines Lage- und Hhensystems aus importierten ALKIS-Daten ermitteln>
* 
* <In den ALKIS - Daten sind oft Koordinaten aus unterschiedlichen Bezugssystemen enthalten. 
* Sie entscheiden sich beim Import der AKLIS - Daten, welche Koordinaten in Ihr 
* Hauptlagesystem importiert werden sollen. 
* Dieses Beispielskript zeigt, wie Sie die Koordinaten aus anderen Lage- und 
* Hhensystemen aus Ihren importierten ALKIS - Daten ermitteln und protokollieren
* knnen. Dazu whlen Sie das Lage- und Hhensystem aus den ALKIS - Daten aus einer 
* Tabelle. Die Koordinaten der vorhandenen Punkte werden ins Protokollfenster ausgegeben.>
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH/CK
* @endfiledoc
* -----------------------------------------------------------------------------
* @history
* -----------------------------------------------------------------------------
*
$Checklevel 7 
BILDSCHIRM GRAFIK
*
SYMBOLS /TOPOSYS/       TopoSys                                 | Objekt fr das System der Topografiedaten
SYMBOLS /POINTSYS/      PointSys                                | Objekt fr das Punktsystem (Punktdatenbank)
SYMBOLS /AAAINDEX/      AAAIdx;AAAIdx2                          | Index-Objekte zum fortlaufenden auslesen der AAA-Objekte
SYMBOLS /AAAREF/        AAARef;Ref;Position;ObjRef              | Referenzen auf AAA-Objekte
SYMBOLS /AAAOBJECT/     AAAObj;Punktort;AAAPunkt;AAAKoor        | AAA-Objekte
SYMBOLS /AAA_ATTRIBUTE/ AAAKSys;AAAX;AAAY                       | Nebenattribute eines AAA-Objekts
SYMBOLS /COORDINATE/    AAALage;PdbLage                         | Hilfspunkte

SYMBOLS /PointIndex/    PdbIdx                                  | Indexobjekt zum fortlaufenden lesen der Punktdatenbank
SYMBOLS /Point/         Punkt                                   | Punkt aus der Punktdatenbank

SYMBOLS /GENERALCHOICE/ Systemauswahl                           | Auwahltabelle 

SYMBOLS * Id;Id2;Id3;Anz
SYMBOLS * PositionRef;RefClass;IstTeilVonRef
SYMBOLS * !AAAKSys;!LSys;!HSys;!PNR; PKode;!East; East; !North; North; !Hight; Hight; Rechts; Hoch; Hoehe  

* Systeme fr Punkte und Topografiedaten 
TopoSys = Project.GetTopoSys()
PointSys = Project.GetPointSys()

* Coordinate aus Alkis-Lage
AAALage = NewObject /Coordinate/

* Index zum fortlaufenden Auslesen von AAA-Objekten
AAAIdx = TopoSys.GetAAAIndex()

* Auswahltabelle fr Koordinatesysteme aus AAA-Objekten anlegen
Systemauswahl = NEWOBJECT /GENERALCHOICE/
Systemauswahl.SetCaption("Koordinatensystem aus ALKIS-Daten auswhlen") 
Systemauswahl.SetSortMode(1)  
Systemauswahl.SetHeadLine("System";"")

* Koordinatensysteme aus AAA-Objekten ermitteln und aus Tabelle auswhlen
* Werte vorbelegen
!LSys = " "
!HSys = " "
* Schleife ber alle AAA-Objekte, Koordinatensysteme ermitteln und in Auswahltabelle schreiben
Id = 0 
WHILE AAAObj = AAAIdx.GetNext()
  AAAKSys = AAAObj.GetAttributeItem("srsName")          | Attribut fr Koordinatensystem ermitteln
  IF AAAKSys <> $NULL THEN
    !AAAKSys = AAAKSys.GetCharValue()                   | Inhalt des Attributs als Text liefern
    IF Systemauswahl.FindName(!AAAKSys) == $UNDEF THEN  | Wenn der Text(Name des Koor-Systems) noch nicht in der Liste steht,..
      Id = Id+1
      Systemauswahl.AddItem(!AAAKSys;"";Id;0)           | Name des Koor-Systems zur Liste zufgen
    END IF
  END IF 
END WHILE

* Auswahl Lagesystem
Id2 = 0
Id2 = Systemauswahl.Choose(Id2)                         | 1. Auswahl: Name des Lagesystems
!LSys = Systemauswahl.GetName(Id2) 
IF T_EQUAL(!LSys;" ") THEN 
  Report " kein Lagesystem gewhlt"
ELSE
  Report "gewhltes Lagesystem '#'";!LSYS  
END IF
* Auswahl Hhensystem
Id3 = 0
Id3 = Systemauswahl.Choose(Id3)                         | 2. Auswahl: Name des Hhensystems
!HSys = Systemauswahl.GetName(Id3) 
IF T_EQUAL(!HSys;" ") THEN 
  Report " kein Lagesystem gewhlt"
ELSE
  Melde "gewhltes Hhensystem '#'";!HSYS  
END IF

* Filter fr zu durchsuchende AAA-Objekte setzen
* Klassenfilter setzen ber AX_PunktortTA; AX_PunktortTU; AX_PunktortAU; AX_PunktortAG
AAAIdx.SetClassIDFilter(TopoSys.AAAClassID("AX_PunktortAG"))
AAAIdx.SetClassIDFilter(TopoSys.AAAClassID("AX_PunktortAU"))
AAAIdx.SetClassIDFilter(TopoSys.AAAClassID("AX_PunktortTA"))
AAAIdx.SetClassIDFilter(TopoSys.AAAClassID("AX_PunktortTU"))

* Attributfilter fr Lagesystem setzen 
AAAIdx.SetAttrFilter("srsName";!LSys)

* Schleife ber alle (gefilterten) Punktorte
Anz = 0
WHILE Punktort = AAAIdx.GetNext()                     | Alle gefundenen Punktorte durchgehen
  Anz = Anz + 1

  * ALKIS Aufnahmepunkt holen fr den der Punktort gilt (AX_Aufnahmepunkt)    
  Ref = Punktort.GetRefByClass(TopoSys.AAARefClassID('istTeilVon');0;0)
  
  IF Ref <> $NULL THEN
    AAAPunkt = Ref.GetAAAObject()                     | ALKIS Aufnahmepunkt
  
    *   CARD/1 Punkt aus Punktdatenbank Zu ALKIS Aufnahmepunkt ermitteln  
    Position = AAAPunkt.GetRefByClass(TopoSys.AAARefClassId("position");0; 0) 
    Punkt  = Position.GetPoint()
    Rechts = Punkt.GetX()
    Hoch   = Punkt.GetY()
    Hoehe  = Punkt.GetZ()    
  
    * Punkt in Grafik darstellen
    AAALage = Punkt.GetCoordinate()
    AAALage.Draw(7;3)
   
    * Punktnummer, Kode und Koordinaten aus ALKIS Aufnahmepunkt ermitteln
    !PNR   = !!Punkt.GetName()
    PKode  = Punkt.GetCode()
    !East  = !!Punktort.GetAttribute("rechtswert")
    East   = WERTAUSTEXT(!East)
    !North = !!Punktort.GetAttribute("hochwert")
    North  = WERTAUSTEXT(!North)
    
    *  Hhe zu HhenKoordinatensystem ermitteln
    * Index anlegen und Filter ber den Aufnahmepunkt und Hhensystem setzen
    AAAIdx2 = TopoSys.GetAAAIndex()
    AAAIdx2.SetAttrFilter("srsName";!HSys)
    AAAIdx2.SetReferenceFilter( AAAPunkt.GetClassID(); 0; AAAPunkt.GetID() )
  
    AAAKoor =  AAAIdx2.GetNext()       
    IF AAAKoor <> $NULL THEN                          | Hhe vorhanden
      !Hight = !!AAAKoor.GetAttribute("hoehe")
      Hight  = WERTAUSTEXT(!Hight)
    ELSE                                              | keine Hhe vorhanden
      Hight = $UNDEF   
    END IF
  
    * Protokollausgabe der gefundenen Punkte (Nr., Kode, AAA-Koordinaten (East, North, Height), Koordinaten im Hauptlagesystem (Rechts, Hoch, Hoehe) 
    Melde "Punktnummer: '#' Kode: # East: #######.### North: #######.### Height: #####.###  / Rechts: #######.### Hoch: #######.### Hhe: #####.###";!PNR;PKode;East;North;Hight;Rechts;Hoch;Hoehe
  END IF
END WHILE
stop







