VERSION 8000;;8413
* Achse_WeichenListen.CSX  17.02.10
* -----------------------------------------------------------------------------
* @filedoc
* @file Achse_WeichenListen.CSX
* @brief Weichen protokollieren 
* 
* Dieses Beispielskript protokolliert fr eine Achse alle vorhandenen Weichen. 
* Hierfr geben Sie die Achsnummer im Dialog ein.
* Zu einer Weiche werden folgende Informationen ausgegeben: 
* Weichennummer, Achsnummer des durchgehenden und des abzweigenden Gleises, 
* Weichentyp, Weichenstatus, Art und Form des Herzstcks.
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author CK
* @endfiledoc
* -----------------------------------------------------------------------------
* @history
* 8413  9.10.12 CK:Dialog umgestellt und Hilfe ergnzt
* -----------------------------------------------------------------------------

* --- Vereinbarungen ----------------------------------------------------------

BILDSCHIRM GRAFIK
*
* --- Deklarationen -----------------------------------------------------------

SYMBOLE /ALIGNMENTSYS/ AchsSys                         | Symbol fr das System der Achsen
SYMBOLE /ALIGNMENT/ Achse                              | Symbol fr die Achse
SYMBOLE /SWITCH/ Weiche                                | Symbol fr die Weiche
SYMBOLE * AchsNr; !WName; WTyp; !WTyp; WStatus; !WStatus; WHerzA; !WHerzA; WHerzF; !WHerzF  

HILFE SYMBOL "Weichen_listen";"SKRIPTE_BEISPIELE_ACHSEN"

AchsNr = 0

* --- Ausfhrungen-------------------------------------------------------------

AchsSys = Project.GetAlignmentSys()                    | liefert das Objekt fr das System der Achsen 

* Dialog 
SYMBOLE /DLG_WINDOW/ Dialog                                            | Dialogfenster
SYMBOLE /DLG_ALIGNMENT/ DF_Achse
SYMBOLE * Ret
Dialog = NewObject /DLG_WINDOW/                       | Anlegen des Dialogfensters
Dialog.SetCaption("Weichen protokollieren")     | berschrift des Fensters 
Dialog.SetHelp("Weichen_listen")
  
DF_Achse = NewObject /DLG_ALIGNMENT/
DF_Achse.SetLabel("Achse:")
DF_Achse.SetNumber(AchsNr)
Dialog.AddField(DF_Achse)

Ret = Dialog.DoDialog()
  
WENN Ret == 1 DANN
  AchsNr= DF_Achse.GetNumber()
SONST
  Stop
WEITER
*
Achse = AchsSys.GetAlignment(AchsNr)                   | liefert das Achsobjekt
!AchsBez = Achse.GetDescription()                      | liefert die Achsbezeichung 

* Protokollausgabe 
MELDE "-------------------------------------------------------"
MELDE " Weichenliste fr Achse #; # "; AchsNr; !AchsBez
MELDE "-------------------------------------------------------"

MELDE " Weiche        |      Achsen        |  Typ            | Status    |          Herzstck        "
MELDE "               |  durchg. | abzwg.  |                 |           |    Form       |  Art      "
MELDE "------------------------------------------------------------------------------------------------"
 
* Schleife ber alle Weichen der Achse
SOLANGE Weiche=Achse.GetNextSwitch(Weiche)
   WENN Weiche == $NULL DANN ABBRUCH SOLANGE                   
   !WName = Weiche.GetName()                                   | Weichenname ermitteln
   DGleis = Weiche.GetAlignmentThrough()                       | durchgehende Gleisachse ermitteln
   TEXTGEN !DGLEIS; "# "; DGleis  
   WENN DGleis = AchsNr DANN !DGleis = " "                     | wenn durchgehende Gleisachse die gewhlte Achse ist, keine Ausgabe  
   AGleis = Weiche.GetAlignmentDiv()                           | abzweigende Gleisachse ermitteln
   TEXTGEN !AGLEIS; "# "; AGleis         
   WENN AGleis = AchsNr DANN !AGleis = " "                     | wenn abzweigende Gleisachse die gewhlte Achse ist, keine Ausgabe

   WTyp = Weiche.GetSwitchType()                               | Weichentyp ermitteln
   !WTyp = !TypeBez_W(WTyp)                                    | Funktion !TypeBez_W gibt Weichentyp in Klartext aus (s.u.)  

   WStatus = Weiche.GetCalculationStatus()                     | Weichenstatus ermitteln
   WENN WStatus = 0 DANN !WStatus = "gltig"                   | Weichenstatus in Klartext ausgeben
   WENN WStatus = 1 DANN !WStatus = "ungltig"                   

   WHerzA = Weiche.GetNoseType()                               | Art des Weichenherzstcks ermitteln 
   WENN WHerzA = 0 DANN !WHerzA = "fest"                       | Art des Weichenherzstcks in Klartext ausgeben  
   WENN WHerzA = 1 DANN !WHerzA = "federnd "
   WENN WHerzA = 2 DANN !WHerzA = "gelenkig "
   
   WHerzF = Weiche.GetNoseProfile()                            | Form des Weichenherzstcks ermitteln
   WENN WHerzF = 0 DANN !WHerzF = "gerade"                     | Form des Weichenherzstcks in Klartext ausgeben
   WENN WHerzF = 1 DANN !WHerzF = "gebogen"

   MELDE " ############  |     #### |    #### |   ##############| ########  |   #######     | #";!WName;!DGleis;!AGleis;!WTyp;!WStatus;!WHerzF;!WHerzA   
    
ENDE SOLANGE

MELDE "-----------------------------------------------------------------------------------------------------"

STOP

* --- Funktionen ------------------------------------------------------------
* @function TypeBez_W
* @brief Weichentyp im Klartext liefern
* @param Typ: Typnummer der Weiche 
*
* @return !Typ: Bezeichnung des Weichentyps als Text
*

FUNKTION !TypeBez_W : Typ
SYMBOLE * !Typ
  WENN Typ == 1 DANN !Typ = "EW"
  WENN Typ == 2 DANN !Typ = "sym ABW"
  WENN Typ == 3 DANN !Typ = "Sonderform"
  WENN Typ == 11 DANN !Typ = "Sonderform NL"
  WENN Typ == 21 DANN !Typ = "Sonderform CN "
  WENN Typ == 31 DANN !Typ = "Sonderform MSB"
  WENN Typ == 101 DANN !Typ = "Kreuzung"
  WENN Typ == 102 DANN !Typ = "EKW"
  WENN Typ == 103 DANN !Typ = "DKW"
  ZURCK !Typ
ENDE FUNKTION
* -----------------------------------------------------------------------------