VERSION 8000; ; 8411
* -----------------------------------------------------------------------------
* @filedoc
* @file Plot_Punkte_einfach.CSX
* @brief Lageplanzeichnung fr Punkte erstellen 
* 
* Dieses Beispielskript erstellt eine Lageplanzeichnung fr alle oder
* nur fr markierte Punkte (Punkte.PLT).
* Fr die Zeichnungserstellung wird der Globale Blattschnitt $LAGE verwendet 
* Als Beschriftung sind Punktnummer und Punkthhe vorgesehen.
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author BS
* @endfiledoc
* -----------------------------------------------------------------------------
*    8411 08.08.12 BH  Umstellung auf neue Dialoge 
* @history
* -----------------------------------------------------------------------------

* Vereinbarungen --------------------------------------------------------------
$PRFSTUFE 7
BILDSCHIRM GRAFIK   | gibt die Meldungen im Arbeitsprotokoll aus

* Deklarationen  --------------------------------------------------------------

  SYMBOLE /POINTSYS/ PointSys                                | Symbol fr System der Punkte
  SYMBOLE /POINT/ Punkt                                      | Symbol fr den Punkt
  SYMBOLE /POINTINDEX/ XPunkt                                | Symbol fr Punktindex

  SYMBOLE * !PltName;!PltBez;!PltLgr;!PltLay1                | Textsymbole fr den Dialog 
  SYMBOLE * PuAusw;PNPl;PHPl;SymNr;Stift1;Stift2;Stift3      | Wertsymbole fr den Dialog
  SYMBOLE * !PuNum;!PuHoe;Rechts;Hoch                        | Symbole fr Zeichnungserstellung

  SYMBOLE * RET

* Voreinstellungen 
  !PltName = "Punkte.PLT"                                    | Name der PLT-Datei
  !PltBez  = "Lageplanzeichnung mit globalem Blattschnitt"   | Bezeichnung der PLT-Datei
  !PltLgr  = "Punkte_$Lage"                                  | Name der Layergruppe
  !PltLay1 = "Punkte_1"                                      | Name des Layers
  Stift1    = 1                                              | Stift fr Punktsymbol
  Stift2    = 1                                              | Stift fr Punktnummer
  Stift3    = 1                                              | Stift fr Punkthhe
  PNPl = 1                                                   | Punktnummer anschreiben
  PHPl = 1                                                   | Punkthhe anschreiben
  PuAusw = 1                                                 | Punktauswahl
  SymNr = 2                                                  | Symbolnummer 

* Ausfhrungen -----------------------------------------------

* Dialogeingabe
Ret = DIALOG_PuPlot_einfach()

*....................Protokollausgabe
  WENN PuAusw = 1 DANN  
    Melde "Punktauswahl    alle Punkte"
  SONST
    Melde "Punktauswahl    markierte Punkte"
  WEITER
  WENN PNPl = 1 DANN 
    MELDE "Punktnummern zeichnen    ja"
  SONST
    MELDE "Punktnummern zeichnen    nein"
  WEITER
  WENN PHPl = 1 DANN
    MELDE "Punkthhen zeichnen    ja"
  SONST
    MELDE "Punkthhen zeichnen    nein"
  WEITER
    MELDE "SymbolNr  #";SymNr
 
* Zeichnungsdatei ffnen
PLT_DAT_NEU !PltName; !PltBez                           | legt eine neue Zeichnungsdatei an
PLT_LGR_LAGE !PltLgr; "Globaler Blattschnitt"; "$LAGE"  | legt fr die aktuelle Zeichnungsdatei eine Layergruppe an
PLT_LAY_NEU !PltLay1; "Punkte_Info"                     | legt fr die aktuelle Layergruppe ein Layerobjekt an 

* Systemobjekt
PointSys = Project.GetPointSys()

* Punktindexobjekt
XPunkt = PointSys.GetPointIndex()
WENN PuAusw == 2 DANN XPunkt.SetMarkFilter(1)          | setzt Filter ber markierte Punkte (bei Option 2)

* Schleife ber alle Punkte: Punkte mit Symbol und Beschriftung zeichnen 
SOLANGE Punkt = XPunkt.GetNext()
  WENN Punkt == $NULL DANN ABBRUCH SOLANGE

  * Punktkoordinate
  Rechts = Punkt.GetX()
  Hoch = Punkt.GetY()
  PLT_STIFT Stift1
  PLT_SYM_VERW SymNr; Rechts; Hoch; 1; 1; 0
  * Punktnummer
  WENN PNPl == 1 DANN
    !PuNum = Punkt.GetName()
    PLT_STIFT Stift2
    PLT_TEXT !PuNum; 1; ROA; PHF; Rechts; Hoch
  WEITER
  * Punkthhe
  WENN PHPl == 1 DANN
    TEXTGEN !PuHoe; "#.###"; Punkt.GetZ()
    PLT_STIFT Stift3
    PLT_TEXT !PuHoe; 1; RUA; PHF; Rechts; Hoch
  WEITER

ENDE SOLANGE

* Zeichnungsdatei schlieen
PLT_DAT_ZU                                               

MELDUNG NEUTRAL "Lageplanzeichnung fr Punkte erstellt"

STOP

* -----------------------------------------------------------------------------
* @function DIALOG_PuPlot_einfach
* @brief <Einfacher Dialog zu Punkte zeichnen>
*
* @ingroup
* @author BH
* @endfunction
FUNKTION DIALOG_PuPlot_einfach:
* Deklarationen fr den Dialog
  SYMBOLE /DLG_WINDOW/ Dialog
  SYMBOLE /DLG_COMBOBOX/ DLGCombo
  SYMBOLE /DLG_CHECKBOX/ DLGCheck1; DLGCheck2       
  SYMBOLE /DLG_SYMBOL/ DLGSymbol 
  SYMBOLE /DLG_FRAME/ DLGFrame1;DLGFrame2

  SYMBOLE * RET

  EXTERN * !PltName;!PltBez;!PltLgr;!PltLay1                | Textsymbole fr den Dialog 
  EXTERN * PuAusw;PNPl;PHPl;SymNr;Stift1;Stift2;Stift3      | Wertsymbole fr den Dialog

*..................Dialog anlegen
  Dialog = NewObject /DLG_WINDOW/
  Dialog.SetHelp("Allgemein")
  Dialog.SetCaption("Lageplanzeichnung fr Punkte erstellen - einfach")
* .................. Rahmen anlegen
  DLGFrame1 = Dialog.CreateFrame(0;"Punktauswahl")
  DLGFrame2 = Dialog.CreateFrame(0;"Darstellung")

*...................Felder anlegen  

*...................Feld fr Combobox
  DLGCombo = NewObject /DLG_COMBOBOX/
  DLGCombo.SetLabel("Punktauswahl           ") 
  DLGCombo.AddText("alle Punkte"; 1) 
  DLGCombo.AddText("markierte Punkte"; 2) 
  DLGCombo.SetValue(PuAusw)
  DLGFrame1.AddField(DLGCombo)

*..................Feld fr Symbolnummer mit Auswahl
  DLGSymbol = NewObject /DLG_SYMBOL/
  DLGSymbol.SetNumber(SymNr)
  DLGSymbol.SetLabel("Symbol:")
  DLGFrame2.AddField(DLGSymbol)

*...................Feld fr Checkbox
  DLGCheck1 = NewObject /DLG_CHECKBOX/
  DLGCheck1.SetBoxLabel("Punktnummer beschriften")
  DLGCheck1.SetFieldLabel(" ")
  DLGCheck1.SetValue(PNPl)
  DLGFrame2.AddField(DLGCheck1)

  DLGCheck2 = NewObject /DLG_CHECKBOX/
  DLGCheck2.SetBoxLabel("Punkthhe beschriften")
  DLGCheck2.SetFieldLabel(" ")
  DLGCheck2.SetValue(PHPl)
  DLGFrame2.AddField(DLGCheck2)

*....................Dialog ausfhren
  Ret = Dialog.DoDialog(1)
*....................Ergebnis
  WENN Ret DANN
    Wenn Dialog.IsChanged() Dann Melde "Werte gendert!"
    PNPl = DLGCheck1.GetValue()
    PHPl = DLGCheck2.GetValue()
    PuAusw = DLGCombo.GetValue()
    SymNr = DLGSymbol.GetNumber()
  Weiter
zurck Ret
Ende Funktion
*
HILFE TEXT Allgemein
' '
' Mit diesem CARDSkript erstellen Sie eine Lageplanzeichnung  '
' fr Punkte der Punktedatenbank. '
' '
' Sie knnen zwischen allen und markierten Punkten whlen.'
' '
' Fr die Darstellung knnen Sie ein Symbol auswhlen. '
' '
' Punktnummer und Punkthhen knnen als Texte angeschrieben werden.'
' '
' Voreinstellungen: '
' '
' Fr alle Daten wird Stift 1 verwendet. '
' '
' Name des Blattschnittes:      $LAGE'
' Name der PLT-Datei:           Punkte.PLT'
' Name des Layers:              Punkte_1' 
' '
ENDE HILFE
