VERSION 8000; ; 8300
* -----------------------------------------------------------------------------
* @filedoc
* @file Prof_PunkteAusProfillinie.CSX
* @brief Lagekoordinaten von Profilpunkten berechnen
* 
* Dieses Beispielskript berechnet die Lagekoordinaten von Profilpunkten
* und gibt diese in eine Datei im CSV-Format aus (Datei: Profilpunkte.CSV).
* Neben der Lagekoordinate enthlt die CSV-Datei Station, Punkthhe, 
* Profilpunktindex und Profil-punktnummer.
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH
* @endfiledoc
* -----------------------------------------------------------------------------
* @history
* -----------------------------------------------------------------------------
* 

* Vereinbarungen --------------------------------------------------------------

BILDSCHIRM GRAFIK                            | gibt die Meldungen im Arbeitsprotokoll aus
SYSTEM.SetDrawPacket("Last_CardSkript_temp") | definiert ein Grafikpaket

* Deklarationen ---------------------------------------------------------------

SYMBOLE /XSECTIONSYS/ XSectionSys            | Symbol fr System der Querschnitte einer Achse
SYMBOLE /XSECTION/ Querschnitt               | Symbol fr den Querschnitt
SYMBOLE /XSECTIONLINE/ QLinie                | Symbol fr die Profillinie
SYMBOLE /XSECTIONPOINT/ QPunkt               | Symbol fr den Profilpunkt
SYMBOLE /COORDINATE/ Koordinate              | Symbol fr den Hilfspunkt

SYMBOLE * Ax; PrL_Nr; AStat; EStat; !CSV_Name; !CSV_Bez
SYMBOLE * QPZ; QPT; ID; Ende_ID; Station

Ax = ACHS_WAHL(1)                            | Auswahl der Achse im Dialog         
AKTACHSE Ax; 0                               | Setzen der aktuellen Achse
AStat = AXSTAT(1;0)                          | Anfangsstation der aktuellen Achse (siehe AKTACHSE)
EStat = AXSTAT(2;0)                          | Endstation  der aktuellen Achse (siehe AKTACHSE)
AStat = AStat + 40
EStat = EStat - 50
PrL_Nr = 10                                  | Nummer der Profillinie
!CSV_Name = "Profilpunkte.csv"               | Name der CSV-Datei
!CSV_Bez = "Profilpunkte als Koordinaten"    | Bezeichnung der CSV-Datei

* Ausfhrungen ----------------------------------------------------------------

* Systemobjekt
XSectionSys = Project.GetXSectionSys(Ax)

*  CSV-Datei anlegen und ffnen
DAT_NEU 1; NAME = !CSV_Name; BEZ = !CSV_Bez
DAT_SCHREIBEN 1; "Station; Rechtswert; Hochwert; Hhe; Profilpunktindex; Profilpunktnummer" 

* Querschnittobjekt
Querschnitt = $NULL
* Schleife ber alle Querschnitte der Achse mit Profillinie PrL_Nr
SOLANGE Querschnitt = XSectionSys.GetNextXSection(Querschnitt; PrL_Nr)
  * Pfen, ob Querschnitt im angegeben Stationsbereich liegt
  Station = Querschnitt.GetChainage()
  WENN Station < AStat @ Station > EStat DANN NCHSTE SOLANGE   
  * Profillinienobjekt
  QLinie =  Querschnitt.GetLine(PrL_Nr)             | liefert die Profillinie an dieser Station
  WENN QLinie == $NULL DANN NCHSTE SOLANGE         | nchste Station, wenn Profillinie an dieser Station nicht vorhanden ist
  Ende_ID = QLinie.GetPointCount()                  | liefert die Anzahl der Profilpunkte

  * Schleife ber alle Punkte der Profillinie
  SCHLEIFE ID = 1; Ende_ID
    * Profilpunktobjekt
    QPunkt = QLinie.GetPoint(ID)                       | liefert den Profilpunkt ber den Index
    QPZ = QPunkt.GetZ()                                | liefert den Z-Wert (Hhe) des Profilpunktes
    QPT = QPunkt.GetT()                                | liefert den T-Wert (Abstand von der Achse) des Profilpunktes
    Koordinate = Querschnitt.GetLateralCoordinate(QPT) | liefert die Lagekoordinate des Profilpunktes
    Koordinate.Draw(5; 5)                              | visualisiert die Koordinate in der Lageansicht
    DAT_SCHREIBEN 1; "#.###; #.###; #.###; #.###; #####; #####"; Station; Koordinate.GetX(); Koordinate.GetY(); QPZ; ID; QPunkt.GetNumber()
  ENDE SCHLEIFE
 
ENDE SOLANGE