VERSION 8000; ; 8411

* -----------------------------------------------------------------------------
* @filedoc
* @file Topo_TexteManipulieren.CSX
* @brief Topografietexte manipulieren 
*
* Dieses Beispielskript manipuliert Topografietexte anhand von EDBS-Flurstcksnummern aus Thringen.
* Beispiel: aus "FT16232900800927000400" wird "927$_4"
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author IGM
* @endfiledoc
* -----------------------------------------------------------------------------
*    8300 19.05.09 JH  bereitgestellt
*    8411 09.08.12 JH  auf neue Dialoge umgestellt und Hilfe ergnzt
* @history
* -----------------------------------------------------------------------------

 
* --- Vereinbarungen ----------------------------------------------------------

BILDSCHIRM GRAFIK                   | gibt die Meldungen im Arbeitsprotokoll aus
$PRFSTUFE 7

* --- Explizite Deklarationen -------------------------------------------------

SYMBOLE /TOPOSYS/ Toposys           | Symbol fr das System der Topografiedaten
SYMBOLE /TOPOLAYER/ Schicht         | Symbol fr die Schicht
SYMBOLE /TOPOTEXT/ Text             | Symbol fr Topografietext
SYMBOLE /TOPOTEXTINDEX/ iTx         | Symbol Textindex

SYMBOLE * !Schicht;Ret;FTAnz;!FTText;!Meld


* --- Ausfhrungen ------------------------------------------------------------

* Systemobjekt
TopoSys = Project.GetTopoSys()

*** Dialogfhrung: Schicht im Dialog abfragen

RET = DIALOG()
WENN Ret == 0 DANN STOP

*** Schleife zum Auslesen der Texte ber gesetzte Filter 

* Textindexobjekt: Auswahl der Texte ber Schicht und Inhalt
iTx = TopoSys.GetTextIndex(!Schicht)                       | liefert Textindexobjekt der Schicht
iTx.SetPatternFilter("FT*")                                | setzt Textfilter

FTAnz = 0                                                  | Schleifenzhler

* Textobjekt
SOLANGE Text = iTx.GetNext()                               | liest Texte ber gesetzte Filter aus 
  !FTText = Text.GetText()                                 | liefert den Text
  Text.SetText(!FlstNr(!FTText))                           | Funktionsaufruf: Text umwandeln
  FTAnz = FTAnz + 1
ENDE SOLANGE

TEXTGEN !Meld; "# Texte in Flurstcksnummern gewandelt"; FTAnz
MELDUNG NEUTRAL; !Meld

STOP


* --- Funktionsblcke ----------------------------------------------

* -----------------------------------------------------------------------------
* @function !FlstNr
* @brief Funktion zum Wandeln von Thringer EDBS-Flurstckstexte in CARD/1 Flurstcksnummern
*        Beispiel: aus FT16232900800927000400 wird 927$_4
* @param !Txt: Text, der umgewandelt wird
*
* @ingroup
* @author IGM
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION !FlstNr: !Txt
  SYMBOLE * !Zaehler;!Nenner ;!FlstNrTxt
  !Zaehler = !Null_Weg(!_TEIL(!Txt; 12; 16))               | Funktionsaufruf
  !Nenner = !_TEIL(!Txt; 17; 20)
  
  WENN T_GLEICH(!Nenner; "0000") DANN
    !FlstNrTxt = !Zaehler
  SONST
    !FlstNrTxt = !Zaehler + "$_" + !Null_Weg(!Nenner)
  WEITER
  
  ZURCK !FlstNrTxt
ENDE FUNKTION 

* -----------------------------------------------------------------------------
* @function !Null_Weg
* @brief Funktion zum Lschen fhrender Nullen aus Texten (Text kann auch Buchstaben enthalten!)
* @param !NullTxt: Textteil 
*
* @ingroup
* @author IGM
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION !Null_Weg: !NullTxt
  SYMBOLE * I;Tlen

  TLen = T_LANG(!NullTxt)
  
  SCHLEIFE i = 2; TLen
    WENN T_GLEICH(!_TEIL(!NullTxt; 1; 1); "0") DANN 
      !NullTxt = !_TEIL(!NullTxt; 2; TLen)                 | TLen ist zwar manchmal zu viel, aber dann krzt es automatisch 
    SONST
      ABBRUCH SCHLEIFE
    WEITER
  ENDE SCHLEIFE
  
  ZURCK !NullTxt
ENDE FUNKTION

* -----------------------------------------------------------------------------
* @function DIALOG
* @brief Eingabedialog
*
* @ingroup
* @author Jo
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION DIALOG:
* Deklarationen
  SYMBOLE /DLG_WINDOW/ Dialog  |Symbol fr Dialogfenster
  SYMBOLE /DLG_LAYER/ Schicht  |Symbol fr  Schichtwahl Feld

  EXTERN * !SCHICHT            |Symbol fr Schichtname
  SYMBOLE * Ret                
*..................Dialog anlegen
  Dialog = NEWOBJECT /DLG_WINDOW/ 
  Dialog.SetCaption("EDBS-Flurstcksnummern aus Thringen wandeln ")
  Dialog.SetHelp("Allgemein")

*..................Feld fr Schichtauswahl + Bezeichnung
  Schicht = NewObject /DLG_LAYER/
  Schicht.SetLabel("Schicht mit den Flurstckstexten:")
  Schicht.SetName(!Schicht)           | Vorbelegung mit Schichtname 
  Dialog.AddField(Schicht)  

  Ret = Dialog.DoDialog()
  
*....................Ergebnis 
  WENN Ret DANN                    |Wenn Dialog mit OK besttigt wurde Ret = 1  
    !Schicht = Schicht.GetName()   |Schichtname aus Dialogfeld auslesen
  WEITER 

  ZURCK Ret

ENDE FUNKTION

* -----------------------------------------------------------------------------
HILFE TEXT ALLGEMEIN 
" "
" EDBS-Flurstcksnummern aus Thringen wandeln "
" -------------------------------------------- "
" Dieses Beispielskript zeigt, wie Sie Textinhalte in einer " 
" ausgewhlten Schicht suchen und verndern knnen. "
" Konkret geht es in diesem Beispiel um die Wandlung von "
" EDBS-Flurstcksnummern in CARD/1 Flurstcksnummern. "
" "
" Beispiel: 'FT16232900800927000400' wird in '927$_4' gewandelt. "
" Nach Auswahl der Schicht im Dialog werden alle Texte gesucht, "
" die mit 'FT' beginnen. Aus diesen Texten werden die Textteile "
" 'Flurstckszhler' und 'Flurstcksnenner' herausgesucht und als "
" CARD/1 Text gebildet (ggf. mit '$_' als Unterstreichung des Zhlers). "
" "
ENDE HILFE