VERSION 8000; ; 8300
* -----------------------------------------------------------------------------
* @filedoc
* @file Topo_LinienAusDA49.CSX
* @brief Topografielinien aus ASCII-Daten importieren
* 
* Dieses Beispielskript importiert Punkte und Linien aus ASCII-Daten.
* Konkret geht es in diesem Beispiel um den Import der Datenarten 45 und 49 
* fr DGM Umringe und Bruchkanten, die mit dem Programmsystem STRATIS erzeugt wurden.
*
* Die Punkte werden in die Punktdatenbank gespeichert.
* Die Linien werden nach Typ (Bruchkante / Umring) in verschiedene Schichten
* aufgeteilt. Die Schichten knnen Sie im Dialog whlen.
*
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH
* @endfiledoc
* -----------------------------------------------------------------------------
*     8300 18.05.09 JH
* @history
* -----------------------------------------------------------------------------


* --- Vereinbarungen ----------------------------------------------------------

BILDSCHIRM GRAFIK
$PRFSTUFE 7
*Benutze 'JH_PKT_Funktionen.QPR'
SYMBOLE * !Dat_45;!Ext;!Dat_49;!Schicht1;!Schicht2;!Bez1;!Bez2;LiKode1;LiKode2
SYMBOLE * !Last_Hor;!Last_Pkt;Last_Art;Kode;NeuLin1;NeuLin2;!Bemerkung
* --- Implizite Deklarationen -------------------------------------------------

SYMBOLE * NPkt ;NNPkt ;NAPkt ;NUPkt ;NMPkt
SYMBOLE * Gewaehlt;Modus

NPkt = 0         | Zhler eingelesene Punkte
NNPkt = 0        | Zhler nicht eingelesene Punkte
NAPkt = 0        | Zhler aktualisierte Punkte
NUPkt = 0        | Zhler berschriebene Punkte
NMPkt = 0        | Zhler gemittelte Punkte

Modus = 1
Gewaehlt = 1

!Schicht1 = "DGM Randpolygon"
!BEZ1 = "Randpolygone aus DA49"
LiKode1 = 1
!Schicht2 = "DGM Bruckanten"
!BEZ2 = "Bruchkanten aus DA49"
LiKode2 = 2

*!Ext = "*.REB"
!Dat_45 = "Nach.D45"
!Dat_49 = "Nach.D49"
!Last_Hor = "x"
!Last_Pkt = "X"
Last_Art = 0
Kode = 3333
!Bemerkung = "Import aus DA45"
NeuLin1 = 0
NeuLin2 = 0


* --- Explizite Deklarationen -------------------------------------------------

SYMBOLE * !REBName; Ret; AnzDreieck

* Punktobjekte
SYMBOLE /POINTSYS/ PointSys                      | Symbol fr das Punktsystem
SYMBOLE /POINT/ Punkt; PKT1; PKT2                | Symbole fr Punkte

* Topografieobjekte
SYMBOLE /TOPOSYS/ TopoSys                        | Symbol fr das Topografiesystem
SYMBOLE /TOPOLAYER/ Layer1; Layer2               | Symbole fr Schichten 
SYMBOLE /TOPOLINE/ TopoLine1; TopoLine2          | Symbole fr Linien

* Symbole fr Format Da49
SYMBOLE * P2Lang;!Punkt2;P1Lang;!Punkt1;!KZ;KZ;Lnge;LFDNR;!LFDNR;LINA;!LINA;!LIN;LIN


* --- Ausfhrung --------------------------------------------------------------

* Systemobjekte
PointSys = Project.GetPointSys()
TopoSys = Project.GetTopoSys()
SYMBOLE * AnzPunkt;Protz;IZ;!ZEILE;!Kart
*** Dialogfhrung

Ret = Dialog()
WENN Ret == 0 DANN STOP


*** Schleife zum Lesen der Punktdaten aus DA45

AnzPunkt = 0
Protz = 0
WENN !Dat_45 DANN
DAT_AUF 1; Name = !Dat_45; FEHLER = Ret                    | ffnet Datei
WENN Ret <> 0 DANN  MELDE "*** Datei fr Punkte wurde nicht gefunden!"    |; !Dat_45  

WENN Ret == 0 DANN
  SCHLEIFE Iz = 1; 100000000
    
    DAT_LESEN 1; Ret; "$"; !Zeile                            | liest aktuelle Dateizeile
      WENN Ret <> 0 DANN ABBRUCH SCHLEIFE
      
    Protz = Protz + 1
      WENN Protz == 10000 DANN
        MELDE "Zeile #: # Punkte, # Dreiecke"; Iz; AnzPunkt; AnzDreieck
        Protz = 0  
      WEITER
    
    !Kart = !_TEIL(!Zeile; 1; 2)    
    WENN T_GLEICH(!Kart; "30") DANN DGM_REB_LesPkt30(!Zeile)  | Funktionsaufruf: Dateizeile auswerten
    WENN T_GLEICH(!Kart; "45") DANN DGM_REB_LesPkt45(!Zeile)  | Funktionsaufruf: Dateizeile auswerten
  
  ENDE SCHLEIFE  
WEITER
DAT_ZU 1 
WEITER
*** Schleife zum Lesen der Liniendaten aus DA49

DAT_AUF 2; Name = !Dat_49; FEHLER = Ret                    | ffnet Datei
  WENN Ret <> 0 DANN
    MELDE "*** Datei # nicht gefunden!"; !Dat_49   
    STOP
  WEITER  

* Schichtobjekte 
Layer1 = TopoSys.GetLayerByName(!Schicht1) 
  WENN Layer1 == $NULL DANN
    Layer1 = TopoSys.CreateLayer(!Schicht1;!Bez1)
  SONST
   TopoSys.ClearLines(Layer1)
  WEITER
Layer2 = TopoSys.GetLayerByName(!Schicht2) 
  WENN Layer2 == $NULL DANN
    Layer2 = TopoSys.CreateLayer(!Schicht2;!Bez2)
  SONST 
   TopoSys.ClearLines(Layer2)
  WEITER

SCHLEIFE Iz = 1; 100000000
  
  DAT_LESEN 2; Ret; "$"; !Zeile                            | liest aktuelle Dateizeile
    WENN Ret <> 0 DANN ABBRUCH SCHLEIFE
    
  Protz = Protz + 1
    WENN Protz == 10000 DANN
      MELDE "Zeile #: # Punkte, # Dreiecke"; Iz; AnzPunkt; AnzDreieck
      Protz = 0  
    WEITER
  
  !Kart = !_TEIL(!Zeile; 1; 2)    
  WENN T_GLEICH(!Kart; "30") DANN DGM_REB_LesPkt30 !Zeile | Funktionsaufruf: Dateizeile auswerten
  WENN T_GLEICH(!Kart; "45") DANN DGM_REB_LesPkt45 !Zeile | Funktionsausfruf: Dateizeile auswerten
  WENN AnzPunkt < 2 DANN GEHE ZU E_ENDE                   | Wenn keine Punkte eingelesen wurden abbrechen 
  WENN T_GLEICH(!Kart; "49") DANN                         |DGM_REB_LesLin49 !Zeile
  
  *    Melde "Zeile # Linienzeile lesen";Protz
  *   hier wird nur das einfache Format behandelt
  *------------------einfaches Format----------------------------------------------------
        *         1         2         3         4         5         6         7
        *1234567890123456789012345678901234567890123456789012345678901234567890 
        *49  1  20       1382      1381
  *------------------Format mit ganzen Linienzgen---------------------------------------
        *         1         2         3         4         5         6         7         8
        *12345678901234567890123456789012345678901234567890123456789012345678901234567890 
   *     49  1T 10  1 2590      2592      2579      2590      4234      4233      2482    
   *     49  1T 10  2 4234      2496      2505      2627      2536    
   *     49  2T 10  1 2579      2574      2555    
   *     49  3T 10  1 2531      2505      2536      4218      2549      2619      2566    
   *     49  3T 10  2 2614      2607      2604      2603      2594      2604      2614    
   *     49  3T 10  3 2484      4218      4225      2627      2517      2518      2627    
   *     49  4T 10  1 2505      2504      2496      2482      2504      2627      4218    
   *     49  4T 10  2 2619      2484      2566    
   *     49  5T 10  1 2604      2611      2614      2534      4227      4160      4062    
   *     49  5T 10  2 4132      4110      4102      4132      4235      4062      4171    
   *     49  5T 10  3 4160      2484      4227      2614    
  * -----------------------------------------------------------------------------
    Lnge = T_LANG(!Zeile)
    !LfdNr = !_TEIL(!Zeile; 11; 12)    | laufende Zeilennummer
    LfdNr = WERTAUSTEXT(!LfdNr) 

    !LinA=!_TEIL(!Zeile; 3; 5)         | Nummer der Linie hier der Linientyp
    LinA = WERTAUSTEXT(!LinA)

    !Lin = !_TEIL(!Zeile; 6; 6)        | Art der Linie hier nicht genutzt
    Lin = WERTAUSTEXT(!Lin)
    !KZ = !_TEIL(!Zeile; 8; 9)
    KZ = WERTAUSTEXT(!KZ)              | Kennzahl des Horizonts, laut REB zulssig 10-89

    !Punkt1 = !_TEIL(!Zeile; 13; 20)   | Bezeichnung der Punkte
    P1Lang = T_Lang(!Punkt1)           | Wenn = 0 Dann keine Punktnummer enthalten (Fehlerprfung mglich) 

    !Punkt2 = !_TEIL(!Zeile; 23; 30)   | Bezeichnung der Punkte
    P2Lang = T_Lang(!Punkt2)           | Wenn = 0 Dann keine Punktnummer enthalten (Fehlerprfung mglich)


    WENN LinA == Last_Art DANN
            
      WENN T_GLEICH(!Punkt1; !Last_Pkt) = 1 & LinA == 1 DANN      | Folgezeile einer Linie
        * Punktobjekt       
        Pkt2 = PointSys.GetPoint(!Punkt2)
        TopoLine1.AddPoint(Pkt2)
      SONST
        NeuLin1 = 1  | keine Folgepunktnummer somit neue Linie anfangen
      WEITER

      WENN T_GLEICH(!Punkt1; !Last_Pkt) = 1 & LinA == 2 DANN
        * Punktobjekt      
        Pkt2 = Pointsys.GetPoint(!Punkt2)
        TopoLine2.AddPoint(Pkt2)
      SONST
        NeuLin2 = 2  | keine Folgepunktnummer somit neue Linie anfangen
      WEITER
      
    SONST
          
      Last_Art = 0   | anderer Typ somit Linie neu anfangen
      
    WEITER

    Neu_ANF:
    WENN Last_Art == 0 DANN       |Linie neu anfangen
    
      WENN LinA == 1 DANN
        MELDE "Zeile # Neue Linie Typ1 last #"; iz; Last_Art
        TopoLine1 = TopoSys.CreateLine(Layer1;LiKode1)
        Pkt1 = Pointsys.GetPoint(!Punkt1)
        Pkt2 = Pointsys.GetPoint(!Punkt2)
          TopoLine1.AddPoint(Pkt1)
          TopoLine1.AddPoint(Pkt2)
      WEITER
      
      WENN LINA == 2 DANN
        Melde "Zeile # Neue Linie Typ2 last #";iz;LAST_ART
        TopoLine2 = TopoSys.CreateLine(Layer2;LiKode2)        
        PKT1 = Pointsys.GetPoint(!PUNKT1)
        PKT2 = Pointsys.GetPoint(!PUNKT2)
        TopoLine2.AddPoint(PKT1)
        TopoLine2.AddPoint(PKT2)
      WEITER
      
    SONST
    
        WENN NEULIN1 == 1 & LINA == 1 DANN
          Melde "Zeile # Neue Linie Typ1 last #";iz;LAST_ART
          TopoLine1 = TopoSys.CreateLine(Layer1;LiKode1)
          PKT1 = Pointsys.GetPoint(!PUNKT1)
          PKT2 = Pointsys.GetPoint(!PUNKT2)
          TopoLine1.AddPoint(PKT1)
          TopoLine1.AddPoint(PKT2)
        WEITER
        
        WENN NEULIN2 == 2 & LINA == 2 DANN
          Melde "Zeile # Neue Linie Typ2 last #";iz;LAST_ART
          TopoLine2 = TopoSys.CreateLine(Layer2;LiKode2)        
          PKT1 = Pointsys.GetPoint(!PUNKT1)
          PKT2 = Pointsys.GetPoint(!PUNKT2)
          TopoLine2.AddPoint(PKT1)
          TopoLine2.AddPoint(PKT2)
        WEITER
        
    WEITER  
      
  WEITER
    
  NeuLin1 = 0
  NeuLin2 = 0
  !Last_Pkt = !Punkt2
  !Last_Hor = !KZ
  Last_Art = LinA   
  
ENDE SCHLEIFE  

E_ENDE:

MELDE "# Punkte aus Datei gelesen";AnzPunkt

Wenn NNpkt==1 DANN MELDE "# Punkt bersprungen"; NNpkt
Wenn NNpkt >1 DANN MELDE "# Punkte bersprungen"; NNpkt

Wenn NApkt==1 DANN MELDE "# Punkt ergnzt"; NApkt
Wenn NApkt >1 DANN MELDE "# Punkte ergnzt"; NApkt

Wenn NUpkt==1 DANN MELDE "# Punkt berschrieben"; NUpkt
Wenn NUpkt >1 DANN MELDE "# Punkte berschrieben"; NUpkt

Wenn NMpkt==1 DANN MELDE "# Punkt gemittelt"; NMpkt
Wenn NMpkt >1 DANN MELDE "# Punkte gemittelt"; NMpkt

Wenn Npkt==0 DANN MELDE "Keine neuen Punkte geschrieben"
Wenn Npkt==1 DANN MELDE "# neuen Punkt geschrieben"; Npkt
Wenn Npkt >11 DANN MELDE "# neue Punkte geschrieben"; Npkt

WENN Gewaehlt==0 DANN 
  MELDUNG NEUTRAL "Punkte einlesen abgebrochen"
SONST
  MELDUNG NEUTRAL "Punkte einlesen abgeschlossen"
WEITER



STOP


* --- Funktionsblcke ---------------------------------------------------------

* -----------------------------------------------------------------------------
* @function DGM_REB_LesPkt30
* @brief Datenzeile auswerten
* @param !Zeile: Inhalt der Dateizeile
*
* @ingroup
* @author JH
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION DGM_REB_LesPkt30: !Zeile 
  EXTERN * !Bemerkung;Kode;AnzPunkt

  SYMBOLE * !Nummer; !Wert1; !Wert2; !Wert3; PktNr; X; Y; Z
  AnzPunkt = AnzPunkt + 1
  
  !Nummer = !_TEIL(!Zeile; 13; 20)   | Punktnummer
  !Wert1 = !_TEIL(!Zeile; 51; 60)    | Rechtswert
  !Wert2 = !_TEIL(!Zeile; 61; 70)    | Hochwert
  !Wert3 = !_TEIL(!Zeile; 71; 80)    | Hhe
  
  PktNr = WERTAUSTEXT(!Nummer)      
  X = WERTAUSTEXT(!Wert1) / 1000
  Y = WERTAUSTEXT(!Wert2) / 1000
  Z = WERTAUSTEXT(!Wert3) / 1000
  
  PunktInDB !Nummer; X; Y; Z; Kode; !Bemerkung;[Modus];[Gewaehlt]  | Funktionsausfruf: Punkt in Datenbank speichern
  
ENDE FUNKTION
* -----------------------------------------------------------------------------
* @function DGM_REB_LesPkt45
* @brief Datenzeile auswerten
* @param !Zeile: Inhalt der Datenzeile
*
* @ingroup
* @author JH
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION DGM_REB_LesPkt45: !Zeile 

  EXTERN * !Bemerkung;Kode;AnzPunkt
  SYMBOLE * !Nummer; !Wert1; !Wert2; !Wert3; PktNr; X; Y; Z
  
  AnzPunkt = AnzPunkt + 1
  
  !Nummer = !_TEIL(!Zeile; 3; 9)   | Punktnummer
  !Wert1 = !_TEIL(!Zeile; 11; 20)  | Rechtswert
  !Wert2 = !_TEIL(!Zeile; 21; 30)  | Hochwert
  !Wert3 = !_TEIL(!Zeile; 31; 40)  | Hhe
  
  PktNr = WERTAUSTEXT(!Nummer)
  X = WERTAUSTEXT(!Wert1) / 1000
  Y = WERTAUSTEXT(!Wert2) / 1000
  Z = WERTAUSTEXT(!Wert3) / 1000
  
  PunktInDB !Nummer; X; Y; Z; Kode; !Bemerkung;[Modus];[Gewaehlt]  | Funktionsausfruf: Punkt in Datenbank speichern
  
ENDE FUNKTION

* -----------------------------------------------------------------------------
* @function PunktInDB
* @brief <hier Kurztext eintragen>
* @param !PNr: 
* @param Rechts: 
* @param Hoch: 
* @param Hohe: 
* @param Kode: 
* @param !Bemerkung: 
* @param Modus: 
* @param Gewaehlt: 
*
*  PunktInDB !Nummer; X; Y; Z; Kode; !Bemerkung;[Modus];[Gewaehlt]  | Funktionsausfruf: Punkt in Datenbank speichern
*
* @ingroup
* @author JH
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION PunktInDB: !PNr; Rechts; Hoch; Hohe;Kode;!Bemerkung;Modus;Gewaehlt

  EXTERN /POINTSYS/ PointSys
  SYMBOLE /GENERALCHOICE/ Choice
  SYMBOLE /POINTSYS/ PointSys
  SYMBOLE /POINT/ Punkt
  *Punktobjekt
  EXTERN * NPKT;NMpkt;NUpkt;NApkt;NNpkt
  EXTERN * Modus;Gewaehlt
*  SYMBOLE * Modus;Gewaehlt
  SYMBOLE * Feld;Mode;N_ID;ok
  SYMBOLE * !Bem;!Caption

  Pointsys = Project.GetPointsys()
  Punkt=PointSys.GetPoint(!PNr)
  WENN Punkt <> $NULL DANN
  
    WENN Modus == 1 DANN
      
      Melde "Punkt # bereits vorhanden"; !PNr 
      Melde "Alt : #######.### #######.### ";Punkt.GetEast(); Punkt.GetNorth()
      Melde "Neu : #######.### #######.### ";Rechts; Hoch
      Melde "Diff: #######.### #######.### ";Punkt.GetEast()-Rechts; Punkt.GetNorth()-Hoch
      Melde " "
      
      Choice = newObject /GENERALCHOICE/
      Choice.SetSortMode(0)
      Textgen !Caption; "Mittelungsdialog fr Punkt #"; !PNr
      Choice.SetCaption(!Caption)
      Choice.SetHeadLine("Option";"")
      Choice.AddItem("berspringen"; "einzeln"; 1)
      Choice.AddItem("berspringen"; "alle"; 2)
      Choice.AddItem("Ergnzen";     "einzeln"; 3)
      Choice.AddItem("Ergnzen";     "alle"; 4)
      Choice.AddItem("berschreiben";"einzeln"; 5)
      Choice.AddItem("berschreiben";"alle"; 6)
      Choice.AddItem("Mitteln";      "einzeln"; 7)
      Choice.AddItem("Mitteln";      "alle"; 8)
*      Choice.AddItem("Abbruch";      "alle"; 0)

      Auswahl:
      Gewaehlt = Choice.Choose(N_Id)
      N_Id=Gewaehlt
    WEITER

    Wenn MOD(Gewaehlt;2)<>0 Dann 
      Modus=1
    Sonst
      Modus=2
    Weiter

    Select Gewaehlt
     Case 0
       MELDUNG FRAGE "Wollen Sie den Vorgang wirklich abbrechen?"; ok
       Wenn Ok==1 Dann STOP   | Zurck Abbruch Solange
       Gehe zu Auswahl      
     Case 1;2  | Vorhandene(n) Punkt(e) berspringen
       NNpkt = NNpkt +1
     Case 3;4  | Punktinformationen ergnzen
       WENN Punkt.GetEast() == 0,0 & Punkt.GetNorth() == 0,0 DANN Punkt.SetPosition(Rechts; Hoch)
       WENN Punkt.GetHeight() == 0,0 DANN Punkt.SetHeight(Hohe)
       WENN Punkt.GetCode() < 1 DANN Punkt.SetCode(Kode)
       !Bem = Punkt.GetRemark()
       WENN T_LANG(!Bem) == 0 DANN Punkt.SetRemark(!Bemerkung)
       Punkt.SetMark(1)
       NAPkt = NAPkt + 1
     Case 5;6  | Vorhandene(n) Punkt(e) berschreiben
       Punkt=PointSys.CreatePoint(!PNr; 1)
       Punkt.SetPosition(Rechts; Hoch)
       Punkt.SetHeight(Hohe)
       Punkt.SetCode(Kode)
       Punkt.SetRemark(!Bemerkung)
       Punkt.SetMark(1)
       NUpkt = NUpkt + 1
     Case 7;8  | Punktinformationen ergnzen
       WENN Punkt.GetEast() == 0,0 & Punkt.GetNorth() == 0,0 DANN
         Punkt.SetPosition(Rechts; Hoch)
       SONST 
         Punkt.SetPosition((Punkt.GetEast() + Rechts) / 2; (Punkt.GetNorth() + Hoch) / 2) 
       WEITER
       WENN Punkt.GetHeight() == 0,0 DANN 
         Punkt.SetHeight(Hohe) 
       SONST
         Punkt.SetHeight((Punkt.GetHeight() + Hohe) / 2) 
       WEITER 
       WENN Punkt.GetCode() < 1 DANN Punkt.SetCode(Kode)
       !Bem=Punkt.GetRemark()
       WENN T_LANG(!Bem) == 0 DANN Punkt.SetRemark(!Bemerkung)
       Punkt.SetMark(1)
       NMpkt = NMpkt + 1
    End Select
  SONST                     | Punkt nicht vorhanden. Neu anlegen. 
  
    Punkt=PointSys.CreatePoint(!PNr; 0)
    Punkt.SetPosition(Rechts; Hoch)
    Punkt.SetHeight(Hohe)
    Punkt.SetCode(Kode)
    Punkt.SetRemark(!Bemerkung)
    Punkt.SetMark(1)
    Npkt = Npkt + 1
    
  WEITER

  ZURCK

ENDE FUNKTION

* -----------------------------------------------------------------------------
* @function Dialog
* @brief Eingabedialog
*
* @ingroup
* @author JH
* @endfunction
* -----------------------------------------------------------------------------
FUNKTION Dialog:
* Deklarationen
  SYMBOLE /DLG_WINDOW/ Dialog
  SYMBOLE /DLG_FILENAME/  Datei1;Datei2
  SYMBOLE /DLG_LAYER/ Schicht1;Schicht2
  SYMBOLE /DLG_CODELINE/ Linienkode1;Linienkode2
  SYMBOLE /DLG_FRAME/ Frame1;Frame2
  Extern * !Dat_45;!Ext;!Dat_49;!Schicht1;!Schicht2;!Bez1;!Bez2;LiKode1;LiKode2
  SYMBOLE * Ret;F_Lang
*..................Dialog anlegen
  Dialog = NEWOBJECT /DLG_WINDOW/
  Dialog.SetCaption("Daten importieren - Linien aus DA49")
  Dialog.SetHelp("ALLGEMEIN")
*..................Rahmen anlegen
  F_Lang = 135
  Frame1 = Dialog.CreateFrame(0;"Quell - Daten")
  Frame1.SetSize(F_Lang)                              | Rahmenbreite festlegen
  Frame2 = Dialog.CreateFrame(0;"Ziel - Schichten")  | Rahmen untereinander, sichtbar, mit Beschriftung 
  Frame2.SetSize(F_Lang)

*..................Feld fr Dateinamen und Bezeichnung
  Datei1 = NewObject /DLG_FILENAME/
  Datei1.SetSize(22)
  Datei1.SetLabel("DA45 - Datei:")
  Datei1.EnableEmpty()
  Datei1.EnableExtern()
  Datei1.SetPattern("*.D45")
  Datei1.SetName(!Dat_45)
  Frame1.AddField(Datei1)
  *..................Feld fr Dateinamen und Bezeichnung
  Datei2 = NewObject /DLG_FILENAME/
  Datei2.SetSize(22)
  Datei2.SetLabel("DA49 - Datei:")
  Datei2.SetPattern("*.D49")
  Datei2.EnableExtern()
  Datei2.SetName(!Dat_49)
  Frame1.AddField(Datei2)


*..................Feld fr Schichtauswahl + Bezeichnung
  Schicht1 = NewObject /DLG_LAYER/
  Schicht1.SetLabel("fr Randpolygone:")
  Schicht1.SetName(!Schicht1)           | Vorbelegung mit Schichtname 
  Schicht1.EnableNew()                  | neue Schicht eingeben  
  Schicht1.SetDescription(!Bez1)
  Frame2.AddField(Schicht1)
*..................Feld fr Liniencode + Bezeichnung
  Linienkode1 = NewObject /DLG_CODELINE/
  Linienkode1.SetLabel("Linienkode:")
  Linienkode1.SetCode(LiKode1)
  Frame2.AddField(Linienkode1)
*..................Feld fr Schichtauswahl + Bezeichnung
  Schicht2 = NewObject /DLG_LAYER/
  Schicht2.SetLabel("fr Bruchkanten:")
  Schicht2.SetName(!Schicht2)           | Vorbelegung mit Schichtname 
  Schicht2.EnableNew()                  | neue Schicht eingeben  
  Schicht2.SetDescription(!Bez2)
  Frame2.AddField(Schicht2)  
*..................Feld fr Liniencode + Bezeichnung
  Linienkode2 = NewObject /DLG_CODELINE/
  Linienkode2.SetLabel("Linienkode:")
  Linienkode2.SetCode(LiKode2)
  Frame2.AddField(Linienkode2)
*....................Dialog ausfhren
  Ret = Dialog.DoDialog()
  
*....................Ergebnis
  WENN Ret DANN
    !Dat_45 = Datei1.GetName()
    !Dat_49 = Datei2.GetName()
    !Schicht1 = Schicht1.GetName()
    LiKode1  = Linienkode1.GetCode()
    !Schicht2 = Schicht2.GetName()
    LiKode2  = Linienkode2.GetCode()
    !Bez1 = Schicht1.GetDescription()
    !Bez2 = Schicht2.GetDescription()
  WEITER 
  ZURCK Ret

ENDE FUNKTION


HILFE TEXT ALLGEMEIN
 " "
 " Daten importieren - Linien aus DA49 "
 " ----------------------------------- "
 " Dieses Beispielskript importiert Punkte und Topografielinien "
 " aus ASCII-Daten.Konkret geht es in diesem Beispiel um den Import "
 " der Datenarten 45 und 49 fr DGM Umringe und Bruchkanten, die mit "
 " dem Programmsystem STRATIS erzeugt wurden. Die Punkte werden in "
 " die CARD/1 Punktdatenbank gespeichert. Die Linien werden nach Typ "
 " (Bruchkante / Umring) in verschiedene Schichten aufgeteilt. "
 " Die Schichten knnen Sie im Dialog whlen. Wenn keine Datei fr "
 " Punkte der DA45 gewhlt wurde versucht das Skript die Punkte "
 " aus der DA49-Datei zu lesen. "
 " "
ENDE HILFE