VERSION 8000; ; 8414

* -----------------------------------------------------------------------------
* @filedoc
* @file ZG_StrassenLaengsschnitt.CSX
* @brief Lngsschnittzeichnung im Dialog erstellen
* 
* Dieses Beispielskript erstellt auf Basis der Einfge-Dateien zur RE-Darstellung
* eine Lngsschnittzeichnung.

* Mchten Sie andere Parameter verwenden, so passen Sie diese im Skript oder 
* in den Einfge-Dateien an. Genauso knnen Sie dieses Skript um eigene Parameter ergnzen. 
*
* Voraussetzungen:
* ----------------
* Fr die Erstellung der Lngsschnittzeichnung mssen folgende Dateien im Projekt CARDDEMO
* oder im zentralen Projekt vorhanden sein:
*
*   - GRADDEF.GPL : Definitionen fr Lngsschnittzeichnungen
*   - M_1000.GPL  : Vereinbarung fr Hhenplne im Mastab 1:1000/100
*   - CARD.STL    : Schriftstildefinitionen
*   - RAS_VERM.STF: Stifttabelle
*   - STEMP.PLT mit Objekt "Stempel"
*
* Ergebnisse:
* ----------- 
* Es wird eine Vereinbarung fr Lngsschnittzeichnungen (Datei: GPLaaann.CRD) angelegt und ausgefhrt.
* Die erzeugte Lngsschnittzeichnung wird anschlieend angezeigt.
*  
* -----------------------------------------------------------------------------
* Copyright (C) IB&T
* 
* Gewhrleistung und Nutzung
* 
* Die Nutzung des Skriptes erfolgt stets auf eigene Gefahr. IB&T bernimmt keine
* Gewhr dafr, dass die Nutzung dieses Skriptes zu Ihrem gewnschten Ergebnis
* fhrt. Da CardScripte vorhandene Projektdaten durch Direktzugriff auf die
* jeweiligen Datenbanken auch ohne weitere Sicherheitsabfragen unbemerkt verndern
* oder lschen knnen, erfordert eine Nutzung entsprechende Kenntnisse und groe
* Sorgfalt. IB&T haftet nicht fr eventuell entstehende Datenverluste und
* Folgeschden, die durch die Nutzung von CardScripten entstehen.
*
* -----------------------------------------------------------------------------
* @author JH
* @endfiledoc
* -----------------------------------------------------------------------------
*    8414 09.01.13 JH Auf neue Dialoge umgestellt lauffhig ab Version 8.414 (wegen DLG_CRD)
*                     Umstellung auf Hilfesystem
* @history
* -----------------------------------------------------------------------------
BILDSCHIRM GRAFIK              | gibt die Meldungen im Arbeitsprotokoll aus


SYMBOLE * !DatNam;Ret;Frageret
SYMBOLE * !Projektbez;!Strae;!vonKm;!bisKm;!Ort;!Zeichnung;!Amt;!Bearbeitet;!Gezeichnet;!DatBearb;!DatGezei;!Masstab;!BlNr       
SYMBOLE * Ax_Nr;Dat_Nr;Gr_Nr;Gl_Nr;KFak;FMR;BrtL;BrtR;QueL;QueR;K_BrtL;K_BrtR;K_QueL;K_QueR 
SYMBOLE * !QL;!BL;!QR;!BR;!Dat_Typ;!Bez    
* --- Zuweisungen -------------------------------------------------------------
Ax_Nr  = 1                     | Nummer der Achse
Dat_Nr = 99                    | Nummer der Zeichnungsvereinbarung
Gr_Nr  = 1                     | Nummer der Gradiente
Gl_Nr  = 1                     | Nummer der Gelndelinie
KFak   = 5,00                  | Faktor Krmmungsband
FMR    = 20,0                  | Mastab Rampenband
BrtL   = 1                     | Breiteband links
BrtR   = 2                     | Breiteband rechts 
QueL   = 1                     | Querneigungsband links 
QueR   = 1                     | Querneigungsband rechts
K_BrtL = 0                     | konstante Breite links
K_BrtR = 0                     | konstante Breite rechts
K_QueL = 0                     | konstante Querneigung links
K_QueR = 0                     | konstante Querneigung rechts

!QL = "QUE(QueL)" 
!BL = "BRT(BrtL)"
!QR = "QUE(BrtR)"
!BR = "BRT(QueR)"

!Dat_Typ = "GPL" 
!Bez     = "ber CardScript erzeugte Vereinbarung"

* aktuelle Texte fr Stempelobjekt

!Projektbez = "Projektbezeichnung"
!Strae     = "Hauptstrae"
!vonKm      = "0,0"
!bisKm      = "1000,00"
!Ort        = "Ort"
!Zeichnung  = "Hhenplan"
!Amt        = "Amt  "
!Bearbeitet = "Bearbeiter"
!Gezeichnet = "Zeichner"
!DatBearb   = "September 2008"
!DatGezei   = "Oktober 2008"
!Masstab    = "1:1000"
!BlNr       = "1"

* --- Ausfhrungen ------------------------------------------------------------
RET = DIALOG()
WENN RET == 0 DANN STOP

* ... Aufruf Dialog zum Bearbeiten der Textvariablen 

MELDUNG FRAGE; "Aktuelle Texte fr Stempelfeld eingeben?"; FrageRet
WENN FrageRet == 1 DANN 
  Ret = Stempel_Dialog()
  WENN RET == 0 DANN STOP
WEITER


* ----------------------------------------------------------

* Querneigung links
WENN QueL == 0 DANN
  TEXTGEN !QL; "#.##"; K_QueL 
SONST
  TEXTGEN !QL; "QUE(#)"; QueL 
WEITER
* Breite links
WENN BrtL == 0 DANN
  TEXTGEN !BL; "#.##"; K_BrtL
SONST
  TEXTGEN !BL; "BRT(#)+ #.##"; BrtL;K_BrtL
WEITER
* Querneigung rechts
WENN QueR == 0 DANN
  TEXTGEN !QR; "#.##"; K_QueR
SONST
  TEXTGEN !QR; "QUE(#)"; QueR
WEITER
* Breite rechts
WENN BrtR == 0 DANN
  TEXTGEN !BR; "#.##"; K_BrtR
SONST
  TEXTGEN !BR; "BRT(#)+ #.##"; BrtR;K_BrtR
WEITER

* bildet den Dateinamen fr die Zeichnungsvereinbarung
!DatNam = !CRDNAME(!Dat_Typ; Ax_Nr; Dat_Nr)

* legt einen neue Vereinbarungsdatei an
DAT_NEU 1; NAME = !DatNam; BEZ = !Bez; DEZ = "COMMA"

* schreibt Inhalte in die Vereinbarungsdatei
DAT_SCHREIBEN 1; "VERSION 8000"
DAT_SCHREIBEN 1; "* generierte Vereinbarung fr Lngsschnittzeichnungen"              
DAT_SCHREIBEN 1; "* -------------------------------------------------- "
DAT_SCHREIBEN 1; " "
DAT_SCHREIBEN 1; "ZRAND STANDARD"
DAT_SCHREIBEN 1; "STEMPEL '<?>STEMP.PLT>STEMPEL'; 0,5; 0,5"
DAT_SCHREIBEN 1; "* -------------------------------------------------- " 
DAT_SCHREIBEN 1; "* definiert Textvariablen, um Platzhaltertexte im Stempelobjekt mit aktuellen Texten zu versehen"
DAT_SCHREIBEN 1; "TEXTVARIABLE Projektbez; '#'"; !ProjektBez 
DAT_SCHREIBEN 1; "TEXTVARIABLE Strae; '#'"; !Strae     
DAT_SCHREIBEN 1; "TEXTVARIABLE vonKm; '#'"; !vonKm      
DAT_SCHREIBEN 1; "TEXTVARIABLE bisKm; '#'"; !bisKm      
DAT_SCHREIBEN 1; "TEXTVARIABLE Ort; '#'"; !Ort        
DAT_SCHREIBEN 1; "TEXTVARIABLE Zeichnung; '#'"; !Zeichnung  
DAT_SCHREIBEN 1; "TEXTVARIABLE Amt; '#'"; !Amt        
DAT_SCHREIBEN 1; "TEXTVARIABLE Bearbeitet; '#'"; !Bearbeitet 
DAT_SCHREIBEN 1; "TEXTVARIABLE Gezeichnet; '#'"; !Gezeichnet 
DAT_SCHREIBEN 1; "TEXTVARIABLE DatBearb; '#'"; !DatBearb   
DAT_SCHREIBEN 1; "TEXTVARIABLE DatGezei; '#'"; !DatGezei   
DAT_SCHREIBEN 1; "TEXTVARIABLE Masstab; '#'"; !Masstab    
DAT_SCHREIBEN 1; "TEXTVARIABLE BlNr; '#'"; !BlNr     
DAT_SCHREIBEN 1; "* --------------------------------------------------- " 
DAT_SCHREIBEN 1; "* Zuweisungen"
DAT_SCHREIBEN 1; "Nr_Gra = #                 | Nummer Gradiente"; Gr_Nr 
DAT_SCHREIBEN 1; "Nr_Gel = #                 | Nummer Gelndelinie"; Gl_Nr
DAT_SCHREIBEN 1; "FaktK = #.###              | Faktor Krmmungsband"; KFak
DAT_SCHREIBEN 1; "!QNL = '#'                 | Querneigung links"; !Ql
DAT_SCHREIBEN 1; "!BRL = '#'                 | Breite links"; !BL
DAT_SCHREIBEN 1; "!QNR = '#'                 | Querneigung rechts"; !QR
DAT_SCHREIBEN 1; "!BRR = '#'                 | Breite rechts"; !Br
DAT_SCHREIBEN 1; "MRamp = #.##               | Mastab Rampenband"; FMR
DAT_SCHREIBEN 1; "* --------------------------------------------------- " 
DAT_SCHREIBEN 1; "DEFOBJEKT 'Gradiente'"
DAT_SCHREIBEN 1; "GRADIENTE NR_GRA;L_GEPL"
DAT_SCHREIBEN 1; "DEFOBJEKT 'Gelnde'"
DAT_SCHREIBEN 1; "PL_LINIE GEL(Nr_Gel); ; L_Vorh"   
DAT_SCHREIBEN 1; "* --------------------------------------------------- " 
DAT_SCHREIBEN 1; "EINFGEN '<?>GRADDEF.GPL'    | Definitionen"  
DAT_SCHREIBEN 1; "EINFGEN '<?>M1_1000.GPL'    | Hhenplan M 1:1000/100"
DAT_SCHREIBEN 1; "* --------------------------------------------------- " 

* schliet die Vereinbarungsdatei
DAT_ZU 1

* startet die Funktionsgruppe "Lngsschnittzeichnung erstellen" und
* fhrt die Zeichnungsvereinbarung aus
STARTE GRADPLOT; ; "AX = ###; NR = ##; AUSF"; Ax_Nr; Dat_Nr
* Alternativ: erzeugt die Zeichnung ohne Starten der Funktionsgruppe
* STARTE "RUN_GRADPLOT@GRADPLOT.DLL"; ; "AX = ###; NR = ##; AUSF"; Ax_Nr; Dat_Nr

STOP

* -----------------------------------------------------------------------------
* @function Dialog
* @brief Dialog 
*
* @ingroup
* @author JH
* @endfunction
FUNKTION Dialog:
* ... Dialoglayout
EXTERN * Ax_Nr;Dat_Nr;Gr_Nr;Gl_Nr;KFak;FMR;BrtL;BrtR;QueL;QueR;K_BrtL;K_BrtR;K_QueL;K_QueR ;!Bez;!Dat_Typ 
SYMBOLE * Ret;FLang    | !QL;!BL;!QR;!BR   

  SYMBOLE /DLG_WINDOW/     DIALOG
  SYMBOLE /DLG_ALIGNMENT/  Achse
  SYMBOLE /DLG_VERTALIGN/  Gradi
  SYMBOLE /DLG_PROFILE/    Gelaende
  SYMBOLE /DLG_WIDTH/      BL;BR
  SYMBOLE /DLG_CROSSFALL/  QL;QR
  SYMBOLE /DLG_NUMBER/     KBL;KBR;KQL;KQR
  SYMBOLE /DLG_NUMBER/     Mass;Fakt
  SYMBOLE /DLG_CRD/        DNR
  SYMBOLE /DLG_FRAME/ Frame1; Frame2;Frame3;Frame4

  DIALOG =   NEWOBJECT /DLG_WINDOW/

  Frame1 = Dialog.CreateFrame(0;"Zeichnungsvereinbarung")
  Frame2 = Dialog.CreateFrame(0;"Hhenverlauf")
  Frame3 = Dialog.CreateFrame(0;"Krmmungsband")
  Frame4 = Dialog.CreateFrame(0;"Querneigungsband")

  FLang = 120 
  Frame1.SetSize(FLang )
  Frame2.SetSize(FLang )
  Frame3.SetSize(FLang )
  Frame4.SetSize(FLang )

  Dialog.SetCaption("Lngsschnittzeichnung nach RE erstellen")
  Dialog.SetHelp("Allgemein")

  Achse = NewObject /DLG_ALIGNMENT/
  Achse.SetNumber(Ax_Nr)
  Achse.SetLabel("Achse:")
  Frame1.AddField(Achse)

  DNR = NewObject /DLG_CRD/
  DNR.SetType(!Dat_Typ)
  DNR.SetLabel("Nr.:")
  DNR.SetNumber(Dat_Nr) 
  DNR.SetDescription(!Bez)
  DNR.EnableNew()
  DNR.SetAlignmentField(Achse)
  Frame1.AddField(DNR)

  Gradi = NewObject /DLG_VERTALIGN/
  Gradi.SetNumber(Gr_Nr)
  Gradi.SetLabel("Gradiente:")
  Gradi.SetAlignmentField(Achse)
  Frame2.AddField(Gradi)

  * Gelnde + Bezeichnung
  Gelaende = NewObject /DLG_PROFILE/
  Gelaende.SetNumber(Gl_Nr)
  * Gelaende.EnableNew()
  Gelaende.SetLabel("Gelnde:")
  Gelaende.SetAlignmentField(Achse)
  Frame2.AddField(Gelaende)
  
  Fakt = NewObject /DLG_NUMBER/
  Fakt.SetLabel("Faktor:")
  fakt.SetSize(7;1)
  Fakt.SetValue(KFak)
  Frame3.AddField(Fakt)



  * Breite + Bezeichnung
  BL= NewObject /DLG_WIDTH/
  BL.SetLabel("Breite links:")
  BL.EnableZero()
  BL.SetNumber(BrtL)
  BL.SetAlignmentField(Achse)
  Frame4.AddField(BL)

  KBL = NewObject /DLG_NUMBER/
  KBL.AppendRight()
  KBL.SetSize(7;2)
  KBL.SetLabel("    +   ")
  KBL.SetValue(K_BrtL)
  Frame4.AddField(KBL)

  *  Querneigung + Bezeichnung
  QL= NewObject /DLG_CROSSFALL/
  QL.SetLabel("Querneigung links:")
  QL.EnableZero()
  QL.SetNumber(QueL)
  QL.SetAlignmentField(Achse)
  Frame4.AddField(QL)

  KQL = NewObject /DLG_NUMBER/
  KQL.AppendRight()
  KQL.SetSize(7;2)
  KQL.SetLabel(" oder ")
  KQL.SetValue(K_QueL)
  Frame4.AddField(KQL )

  *   Breite + Bezeichnung
  BR= NewObject /DLG_WIDTH/
  BR.SetLabel("Breite rechts:")
  BR.EnableZero()
  BR.SetNumber(BrtR)
  BR.SetAlignmentField(Achse)
  Frame4.AddField(BR)

  KBR= NewObject /DLG_NUMBER/
  KBR.AppendRight()
  KBR.SetSize(7;2)
  KBR.SetLabel("    +   ")
  KBR.SetValue(K_BrtR)
  Frame4.AddField(KBR )

  *   Querneigung + Bezeichnung
  QR= NewObject /DLG_CROSSFALL/
  QR.SetLabel("Querneigung rechts:")
  QR.EnableZero()
  QR.SetNumber(QueR)
  QR.SetAlignmentField(Achse)
  Frame4.AddField(QR)

  KQR = NewObject /DLG_NUMBER/
  KQR.AppendRight()
  KQR.SetSize(7;2)
  KQR.SetLabel(" oder ")
  KQR.SetValue(K_QueR)
  Frame4.AddField(KQR )

  *   Masstab fr Band
  Mass = NewObject /DLG_NUMBER/
  Mass.SetLabel("Mastab:")
  mass.SetSize(7;12)
  Mass.SetValue(FMR)
  Frame4.AddField(Mass )

  Ret = Dialog.DoDialog(1)
    
  WENN Ret DANN
    Ax_Nr  = Achse.GetNumber()
    Dat_Nr = DNR.GetNumber()
    !Bez =   DNR.GetDescription()

    Gr_Nr  = Gradi.GetNumber()
    Gl_Nr  = Gelaende.GetNumber()
    KFak   = Fakt.GetValue()
    FMR    = Mass.GetValue()
    BrtL   = BL.GetNumber()
    BrtR   = BR.GetNumber()
    QueL   = QL.GetNumber()
    QueR   = QR.GetNumber()
    K_BrtL = KBL.GetValue()
    K_BrtR = KBR.GetValue()
    K_QueL = KQL.GetValue()
    K_QueR = KQR.GetValue()
  WEITER
  ZURCK RET
ENDE FUNKTION


* -----------------------------------------------------------------------------
* @function Stempel_Dialog
* @brief Dialog fr Textvariablen
*
* @ingroup
* @author JH
* @endfunction
FUNKTION Stempel_Dialog:

  EXTERN * !Projektbez;!Strae;!vonKm;!bisKm;!Ort;!Zeichnung;!Amt;!Bearbeitet;!Gezeichnet;!DatBearb;!DatGezei;!Masstab;!BlNr       
  SYMBOLE * Ret;FLang;Tlang
  SYMBOLE /DLG_WINDOW/ DIALOG
  SYMBOLE /DLG_TEXT/   TextFeld(13)

  DIALOG =   NEWOBJECT /DLG_WINDOW/

  FLang = 80
  TLang = 100 
  DIALOG.SetSize(FLang )
    
  Dialog.SetCaption("Aktuelle Texte fr Stempelfeld")
  Dialog.SetHelp("Allgemein")

  TextFeld(1) = NewObject /DLG_Text/   
  TextFeld(1).SetSize(FLang;TLang)
  TextFeld(1).SetLabel("Projektbezeichnung:")
  TextFeld(1).SetText(!Projektbez)
  Dialog.AddField(TextFeld(1))

  TextFeld(2) = NewObject /DLG_Text/   
  TextFeld(2).SetSize(FLang;TLang)
  TextFeld(2).SetLabel("Strae:")
  TextFeld(2).SetText(!Strae)
  Dialog.AddField(TextFeld(2))

  TextFeld(3) = NewObject /DLG_Text/   
  TextFeld(3).SetSize(FLang;TLang)
  TextFeld(3).SetLabel("von km:")
  TextFeld(3).SetText(!vonKm)   
  Dialog.AddField(TextFeld(3))

  TextFeld(4) = NewObject /DLG_Text/   
  TextFeld(4).SetSize(FLang;TLang)
  TextFeld(4).SetLabel("bis km:")
  TextFeld(4).SetText(!bisKm)     
  Dialog.AddField(TextFeld(4))

  TextFeld(5) = NewObject /DLG_Text/   
  TextFeld(5).SetSize(FLang;TLang)
  TextFeld(5).SetLabel("Ort:")
  TextFeld(5).SetText(!Ort)       
  Dialog.AddField(TextFeld(5))

  TextFeld(6) = NewObject /DLG_Text/   
  TextFeld(6).SetSize(FLang;TLang)
  TextFeld(6).SetLabel("Zeichnung:")
  TextFeld(6).SetText(!Zeichnung) 
  Dialog.AddField(TextFeld(6))

  TextFeld(7) = NewObject /DLG_Text/   
  TextFeld(7).SetSize(FLang;TLang)
  TextFeld(7).SetLabel("Amt:")
  TextFeld(7).SetText(!Amt)       
  Dialog.AddField(TextFeld(7))

  TextFeld(8) = NewObject /DLG_Text/   
  TextFeld(8).SetSize(FLang;TLang)
  TextFeld(8).SetLabel("bearbeitet, Name:")
  TextFeld(8).SetText(!Bearbeitet)
  Dialog.AddField(TextFeld(8))

  TextFeld(9) = NewObject /DLG_Text/   
  TextFeld(9).SetSize(FLang;TLang)
  TextFeld(9).SetLabel("gezeichnet, Name:")
  TextFeld(9).SetText(!Gezeichnet)
  Dialog.AddField(TextFeld(9))

  TextFeld(10) = NewObject /DLG_Text/   
  TextFeld(10).SetSize(FLang;TLang)
  TextFeld(10).SetLabel("bearbeitet, Datum:")
  TextFeld(10).SetText(!DatBearb)  
  Dialog.AddField(TextFeld(10))

  TextFeld(11) = NewObject /DLG_Text/   
  TextFeld(11).SetSize(FLang;TLang)
  TextFeld(11).SetLabel("gezeichnet, Datum:")
  TextFeld(11).SetText(!DatGezei)  
  Dialog.AddField(TextFeld(11))

  TextFeld(12) = NewObject /DLG_Text/   
  TextFeld(12).SetSize(FLang;TLang)
  TextFeld(12).SetLabel("Mastab:")
  TextFeld(12).SetText(!Masstab)   
  Dialog.AddField(TextFeld(12))

  TextFeld(13) = NewObject /DLG_Text/   
  TextFeld(13).SetSize(FLang;TLang)
  TextFeld(13).SetLabel("Blattnummer:")
  TextFeld(13).SetText(!BlNr)      
  Dialog.AddField(TextFeld(13))
    
  Ret = Dialog.DoDialog(1)
    
  WENN Ret DANN
      !Projektbez = TextFeld(1).GetText()
      !Strae     = TextFeld(2).GetText()
      !vonKm      = TextFeld(3).GetText()
      !bisKm      = TextFeld(4).GetText()
      !Ort        = TextFeld(5).GetText()
      !Zeichnung  = TextFeld(6).GetText()
      !Amt        = TextFeld(7).GetText()
      !Bearbeitet = TextFeld(8).GetText()
      !Gezeichnet = TextFeld(9).GetText()
      !DatBearb   = TextFeld(10).GetText()
      !DatGezei   = TextFeld(11).GetText()
      !Masstab    = TextFeld(12).GetText()
      !BlNr       = TextFeld(13).GetText()
  WEITER

  ZURCK RET
ENDE FUNKTION

HILFE SYMBOL "Allgemein";SKRIPTE_BEISPIELE_ZEICHNUNGEN
